import paraview.simple as simple
import paraview.data_exploration as dx

def testStaticLighting(outputdirname):

    resolution = 500
    center_of_rotation = [0.0, 0.0, 0.0]
    rotation_axis = [0.0, 0.0, 1.0]
    distance = 150.0

    wavelet = simple.Wavelet()
    wavelet.WholeExtent = [-20,20,-20,20,-20,20]
    filters = [ wavelet ]
    filters_description = [ {'name': 'Wavelet'} ]

    brownianVectors = simple.RandomVectors()

    calculator1 = simple.Calculator()
    calculator1.Function = 'RTData'
    calculator1.ResultArrayName = 'cRTData'

    calculator2 = simple.Calculator()
    calculator2.Function = 'BrownianVectors'
    calculator2.ResultArrayName = 'cBrownianVectors'

    topfilter = calculator2

    simple.UpdatePipeline()

    color_type = [
        ('SOLID_COLOR', [0.8,0.8,0.8])
        ]
    color_by = [ color_type ]

    color_type = [
        #
        #standard composite type fields examples
        #
        ('POINT_DATA', "RTData"),
        ('POINT_DATA', "BrownianVectors")
        ]

    pdi = topfilter.GetPointDataInformation()
    cdi = topfilter.GetCellDataInformation()

    luts = {
        #
        #standard composite type fields examples
        #
        "RTData": simple.GetLookupTableForArray(
        "RTData", 1, RGBPoints=[
             37, 0.23, 0.299, 0.754,
            207, 0.865, 0.865, 0.865,
             377, 0.706, 0.016, 0.15],
        VectorMode='Magnitude',
        NanColor=[0.25, 0.0, 0.0],
        ColorSpace='Diverging',
        ScalarRangeInitialized=1.0 ),
        "BrownianVectors": simple.GetLookupTableForArray(
        "BrownianVectors", 1, RGBPoints=[
            0, 0.23, 0.299, 0.754,
            0.5, 0.865, 0.865, 0.865,
            1.0, 0.706, 0.016, 0.15],
        VectorMode='Magnitude',
        NanColor=[0.25, 0.0, 0.0],
        ColorSpace='Diverging',
        ScalarRangeInitialized=1.0 ),
        }

    contour_values = [ 64.0, 117.2, 170.4, 223.6 ]

    for iso_value in contour_values:
        simple.Contour(
            Input=topfilter,
            PointMergeMethod="Uniform Binning",
            ContourBy = ['POINTS', 'RTData'],
            Isosurfaces = [iso_value],
            ComputeScalars = 1
            )
        #just to get cell aligned normals for testing
        filters.append(
           simple.PointDatatoCellData(PassPointData = 1)
            )
        color_by.append( color_type )
        filters_description.append({'name': 'iso=%s' % str(iso_value)})

    title = "Composite Static Rendering Test"
    description = "A sample file for static rendering"
    analysis = dx.AnalysisManager( outputdirname, title, description)

    id = 'composite'
    title = '3D composite'
    description = "contour set"
    analysis.register_analysis(id, title, description, '{theta}/{phi}/{filename}', dx.CompositeImageExporter.get_data_type())
    fng = analysis.get_file_name_generator(id)

    camera_handler = dx.ThreeSixtyCameraHandler(
        fng,
        None,
        [ float(r) for r in range(0, 360, 30) ],
        [ float(r) for r in range(-60, 61, 30) ],
        center_of_rotation,
        rotation_axis,
        distance)

    exporter = dx.CompositeImageExporter(
        fng,
        filters,
        color_by,
        luts,
        camera_handler,
        [resolution,resolution],
        filters_description,
        0, 0, 'png')
    exporter.set_analysis(analysis)

    analysis.begin()
    exporter.UpdatePipeline(0)
    analysis.end()

import sys
if len(sys.argv) != 3:
    print "command is 'pvpython makedata.py rgbzplugin_fullpath output_dirname '"
    sys.exit(1)

pluginpath = sys.argv[1]
print "plugin full path is ", pluginpath

try:
    simple.LoadPlugin(pluginpath)
except:
    print "sorry not a valid path to RGBZView library"
    sys.exit(1)

outputdir = sys.argv[2]
print "outputdir is ", outputdir

testStaticLighting(outputdir)
